summary refs log tree commit diff
path: root/arch
diff options
context:
space:
mode:
authorMichael Ellerman <michael@ellerman.id.au>2005-08-03 20:21:23 +1000
committerPaul Mackerras <paulus@samba.org>2005-08-29 10:53:36 +1000
commit56e97b71bf55edb69dc8e9715553972ce50b1564 (patch)
tree2abf3ef9339d3152a7a14c94e6273ecc559ab342 /arch
parent34c8f6961fc601294a38c5bd5ca12131b2e52674 (diff)
downloadlinux-56e97b71bf55edb69dc8e9715553972ce50b1564.tar.gz
[PATCH] ppc64: Rename msChunks structure
Rename the msChunks struct to get rid of the StUdlY caps and make it a bit
clearer what it's for.

Signed-off-by: Michael Ellerman <michael@ellerman.id.au>
Signed-off-by: Paul Mackerras <paulus@samba.org>
Diffstat (limited to 'arch')
-rw-r--r--arch/ppc64/kernel/head.S4
-rw-r--r--arch/ppc64/kernel/iSeries_setup.c17
2 files changed, 11 insertions, 10 deletions
diff --git a/arch/ppc64/kernel/iSeries_setup.c b/arch/ppc64/kernel/iSeries_setup.c
index e47984ba7c7c..b384a6ad0a57 100644
--- a/arch/ppc64/kernel/iSeries_setup.c
+++ b/arch/ppc64/kernel/iSeries_setup.c
@@ -415,20 +415,20 @@ static void __init iSeries_init_early(void)
 	DBG(" <- iSeries_init_early()\n");
 }
 
-struct msChunks msChunks = {
+struct mschunks_map mschunks_map = {
 	/* XXX We don't use these, but Piranha might need them. */
 	.chunk_size  = MSCHUNKS_CHUNK_SIZE,
 	.chunk_shift = MSCHUNKS_CHUNK_SHIFT,
 	.chunk_mask  = MSCHUNKS_OFFSET_MASK,
 };
-EXPORT_SYMBOL(msChunks);
+EXPORT_SYMBOL(mschunks_map);
 
-void msChunks_alloc(unsigned long num_chunks)
+void mschunks_alloc(unsigned long num_chunks)
 {
 	klimit = _ALIGN(klimit, sizeof(u32));
-	msChunks.abs = (u32 *)klimit;
+	mschunks_map.mapping = (u32 *)klimit;
 	klimit += num_chunks * sizeof(u32);
-	msChunks.num_chunks = num_chunks;
+	mschunks_map.num_chunks = num_chunks;
 }
 
 /*
@@ -468,7 +468,7 @@ static void __init build_iSeries_Memory_Map(void)
 
 	/* Chunk size on iSeries is 256K bytes */
 	totalChunks = (u32)HvLpConfig_getMsChunks();
-	msChunks_alloc(totalChunks);
+	mschunks_alloc(totalChunks);
 
 	/*
 	 * Get absolute address of our load area
@@ -505,7 +505,7 @@ static void __init build_iSeries_Memory_Map(void)
 	printk("Load area size %dK\n", loadAreaSize * 256);
 
 	for (nextPhysChunk = 0; nextPhysChunk < loadAreaSize; ++nextPhysChunk)
-		msChunks.abs[nextPhysChunk] =
+		mschunks_map.mapping[nextPhysChunk] =
 			loadAreaFirstChunk + nextPhysChunk;
 
 	/*
@@ -571,7 +571,8 @@ static void __init build_iSeries_Memory_Map(void)
 				     (absChunk > hptLastChunk)) &&
 				    ((absChunk < loadAreaFirstChunk) ||
 				     (absChunk > loadAreaLastChunk))) {
-					msChunks.abs[nextPhysChunk] = absChunk;
+					mschunks_map.mapping[nextPhysChunk] =
+						absChunk;
 					++nextPhysChunk;
 				}
 			}
diff --git a/arch/ppc64/kernel/head.S b/arch/ppc64/kernel/head.S
index a0ff707d6fea..cccec4902646 100644
--- a/arch/ppc64/kernel/head.S
+++ b/arch/ppc64/kernel/head.S
@@ -96,12 +96,12 @@ END_FTR_SECTION(0, 1)
 	.llong hvReleaseData-KERNELBASE
 
 	/*
 	 * At offset 0x28 and 0x30 are offsets to the msChunks
 	 * array (used by the iSeries LPAR debugger to do translation
 	 * between physical addresses and absolute addresses) and
 	 * to the pidhash table (also used by the debugger)
 	 */
-	.llong msChunks-KERNELBASE
+	.llong mschunks_map-KERNELBASE
 	.llong 0	/* pidhash-KERNELBASE SFRXXX */
 
 	/* Offset 0x38 - Pointer to start of embedded System.map */
@@ -96,12 +96,12 @@ END_FTR_SECTION(0, 1)
 
 	/*
-	 * At offset 0x28 and 0x30 are offsets to the msChunks
+	 * At offset 0x28 and 0x30 are offsets to the mschunks_map
 	 * array (used by the iSeries LPAR debugger to do translation
 	 * between physical addresses and absolute addresses) and